package edu.travel.education.web;
import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import edu.travel.education.dto.AddHappyEntryDto;
import edu.travel.education.dto.HappyEntryDto;
import edu.travel.education.entity.HappyEntry;
import edu.travel.education.service.impl.HappyEntryServiceImpl;
import edu.travel.education.vo.HappyEntryVo;
import edu.travel.resp.BaseResponse;
import edu.travel.resp.PageResponse;
import edu.travel.web.BaseController;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import org.springframework.beans.factory.annotation.Autowired;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
* 开心中文报名表(happy_entry)表控制层
*
* @author huangwen
*/
@RestController
@RequestMapping("/happyEntry")
public class HappyEntryController extends BaseController<HappyEntry> {
    @Autowired
    private HappyEntryServiceImpl happyEntryService;

    /**
     * 添加报名表
     * @param happyEntryDto
     * @return
     */
    @PostMapping("/addHappyEntry")
//    @PreAuthorize("permitAll()")
    public BaseResponse<HappyEntryVo> addHappyEntry(@RequestBody AddHappyEntryDto happyEntryDto){
        HappyEntryVo vo = happyEntryService.addHappyEntry(happyEntryDto);
        return new BaseResponse<>(200,"success",vo);
    }

    /**
     * 根据id查询报名表详情
     * @param id
     * @return
     */
   @GetMapping("/getHappyEntryById")
   @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<HappyEntryVo> getHappyEntryById(Long id){
        HappyEntryVo vo = happyEntryService.getHappyEntryById(id);
        return new BaseResponse<>(200,"success",vo);
    }

    /**
     * 根据id修改报名表
     * @param happyEntryDto
     * @return
     */
    @PostMapping("/UpdateHappyEntryById")
    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<HappyEntryVo> UpdateHappyEntryById(@RequestBody HappyEntryDto happyEntryDto){
        HappyEntryVo vo = happyEntryService.UpdateHappyEntryById(happyEntryDto);
        return new BaseResponse<>(200,"success",vo);
    }

    /**
     * 根据id删除报名表
     * @param id
     * @return
     */
    @PostMapping("/deleteHappyEntryById")
    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<HappyEntryVo> deleteHappyEntryById(@RequestParam Long id){
        Set<Long> set = new HashSet<>();
        set.add(id);
        happyEntryService.deleteHappyEntryByIds(set);
        return new BaseResponse<>(200,"success",null);
    }

    /**
     * 根据ids批量删除报名表
     * @param ids
     * @return
     */
    @PostMapping("/deleteHappyEntryByIds")
    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<HappyEntryVo> deleteHappyEntryById(@RequestBody List<Long> ids){
        Set<Long> set = new HashSet<Long>(ids);
        happyEntryService.deleteHappyEntryByIds(set);
        return new BaseResponse<>(200,"success",null);
    }

    /**
     * 分页查询报名表
     * @return
     */
    @GetMapping("/listPageHappyEntry")
    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<List<HappyEntryVo>> listPageHappyEntry( HappyEntryDto happyEntryDto){
        IPage<HappyEntry> page = happyEntryService.listPageHappyEntry(happyEntryDto);
        List<HappyEntryVo> happyEntryVos = BeanUtil.copyToList(page.getRecords(), HappyEntryVo.class);
        return  PageResponse.out(200,"success",happyEntryVos,(int) page.getTotal(),(int)page.getSize());
    }

}
